@@ -1,5 +1,6 @@
 from django.conf import settings
 from django.utils.importlib import import_module
+from django.core.exceptions import ImproperlyConfigured
 
 from ping.defaults import *
 
@@ -45,3 +46,29 @@ def check_database_sites(request):
         return 'db_site', True
     except:
         return 'db_site', False
+
+
+#Caching
+CACHE_KEY = 'django-ping-test'
+CACHE_VALUE = 'abc123'
+
+def check_cache_set(request):        
+    from django.core.cache import cache
+    try:
+        cache.set(CACHE_KEY, CACHE_VALUE, 30)
+        return 'cache_set', True
+    except:
+        return 'cache_set', False
+
+def check_cache_get(request):        
+    from django.core.cache import cache
+    try:
+        data = cache.get(CACHE_KEY)
+        if data == CACHE_VALUE:
+            return 'cache_get', True
+        else:
+            return 'cache_get', False
+    except:
+        return 'cache_get', False
+
+
